==> liquidwar6-0.0.7beta.tar.gz: liquidwar6-0.0.7beta/src/scriptpo-update.sh <==
#!/bin/sh

# Liquid War 6 is a unique multiplayer wargame.
# Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# 
# Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
# Contact author        : ufoot@ufoot.org

# Quick hack to generate a dummy .c file which will then be processed
# by GNU gettext to extract strings for po files and i18n.

SCRIPT_DIR=../script
C_FILE=../src/scriptpo.c

find $SCRIPT_DIR -type f -a -name "*.scm" \
    | xargs sed "s/^.*( *_  *\\(\\\".*\\\"\\) *).*\$/_(\1)\; \\/\\/ extracted by scriptpo-update.sh/g" \
    | grep scriptpo-update.sh \
    > $C_FILE

## Additionnally, we automatically fill ../po/POTFILES.in
#cd ..
#find src -type f -a -name "*.c" \
#    > po/POTFILES.in
#find src -type f -a -name "*.c.inc" \
#    >> po/POTFILES.in
#cd src

# Translating all the source files requires too much time, only
# some specific cherry-picked files are translated.
cd ..
rm po/POTFILES.in
#for i in src/scriptpo.c src/lib/hlp/hlp-reference.c src/lib/sys/sys-log.c src/lib/sys/sys-mem.c src/lib/lw6-print.c src/lib/ldr/ldr-print.c src/lib/*/mod-*/mod-*-backend.c ; do
for i in src/scriptpo.c src/lib/sys/sys-log.c src/lib/sys/sys-mem.c src/lib/lw6-print.c ; do
    echo "$i" >> po/POTFILES.in
done
cd src

indent $C_FILE

==> liquidwar6-0.0.9beta.tar.gz: liquidwar6-0.0.9beta/src/scriptpo-update.sh <==
#!/bin/sh

# Liquid War 6 is a unique multiplayer wargame.
# Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# 
# Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
# Contact author        : ufoot@ufoot.org

# Quick hack to generate a dummy .c file which will then be processed
# by GNU gettext to extract strings for po files and i18n.

SCRIPT_DIR=../script
C_FILE=../src/scriptpo.c

find $SCRIPT_DIR -type f -a -name "*.scm" \
    | xargs sed "s/^.*( *_  *\\(\\\".*\\\"\\) *).*\$/_(\1)\; \\/\\/ extracted by scriptpo-update.sh/g" \
    | grep scriptpo-update.sh \
    > $C_FILE

## Additionnally, we automatically fill ../po/POTFILES.in
#cd ..
#find src -type f -a -name "*.c" \
#    > po/POTFILES.in
#find src -type f -a -name "*.c.inc" \
#    >> po/POTFILES.in
#cd src

# Translating all the source files requires too much time, only
# some specific cherry-picked files are translated.
cd ..
rm po/POTFILES.in
#for i in src/scriptpo.c src/lib/sys/sys-log.c src/lib/hlp/hlp-reference.c src/lib/hlp/hlp-credits.c src/lib/sys/sys-mem.c src/lib/lw6-print.c src/lib/ldr/ldr-print.c src/lib/*/mod-*/mod-*-backend.c ; do
for i in src/scriptpo.c src/lib/sys/sys-log.c src/lib/hlp/hlp-credits.c src/lib/lw6-print.c ; do
    echo "$i" >> po/POTFILES.in
done
cd src

indent $C_FILE
